@@ -20,7 +20,7 @@ import sys
 import freezegun
 import mock
 import OpenSSL
-import pytest
+import pytest  # type: ignore
 import requests
 import requests.adapters
 from six.moves import http_client
@@ -51,6 +51,12 @@ class TestRequestResponse(compliance.RequestResponseTests):
 
         assert http.request.call_args[1]["timeout"] == 5
 
+    def test_session_closed_on_del(self):
+        http = mock.create_autospec(requests.Session, instance=True)
+        request = google.auth.transport.requests.Request(http)
+        request.__del__()
+        http.close.assert_called_with()
+
 
 class TestTimeoutGuard(object):
     def make_guard(self, *args, **kwargs):
